﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Globalization;
using PSC;

/**
 * SOPGClassicMerchantClient Demo Code
 * 
 * @package psc-sdk
 * @copyright 2013 Paysafecard.com Wertkarten AG 
 * @version 1.2
 * @since 0.1
 */

namespace MerchantClientTest
{
    public partial class MainWindow : Form
    {
        private PSC.SOPGClassicMerchantClient client;

        public MainWindow()
        {
            InitializeComponent();

            try
            {
                // Neue Instanz des MerchantClients erzeugen. In diesem Beispiel würde eine Ausnahme bei der
                // Angabe einer ungültigen Systemsprache im Konstruktor ausgelöst werden.
                client = new PSC.SOPGClassicMerchantClient(true, "DE", true, DevStatus.TEST);

                // Jedes Event vom PSC SDK soll an uns weitergeleitet werden:
                client.logMessageEvent += new PSC.SOPGClassicMerchantClient.logMessageEventHandler(client_logMessageEvent);
            }

            catch (ArgumentException argEx)
            {
                InputErrorTxt.Text = argEx.Message;
                procPaymentBtn.Enabled = false;
            }
        }

        void client_logMessageEvent(object sender, Logging.LogMessage logMessage)
        {
            string logTypeStr = "";

            switch (logMessage.logType)
            {
                case Logging.LogType.DEBUG: logTypeStr = "DEBUG"; break;
                case Logging.LogType.ERROR: logTypeStr = "ERROR"; break;
                case Logging.LogType.INFO: logTypeStr = "INFO"; break;
                case Logging.LogType.WARNING: logTypeStr = "WARNING"; break;
            }

            if (logMessage.logType == Logging.LogType.DEBUG)
            {
                logTxtBox.Text += "[" + logTypeStr + "]: " + logMessage.callerFunc + ": " + 
                    logMessage.requResult + "\r\n";

                return;
            }

            logTxtBox.Text += "[" + logTypeStr + "]: " + logMessage.message + ": " + 
                logMessage.callParams + "\r\n";
        }

        // Wird beim Klick auf den Button "Process payment" ausgeführt:
        private void procPaymentBtn_Click(object sender, EventArgs e)
        {
            soapRequTxtBox.Clear();
            logTxtBox.Clear();

            client.DeleteLogMessages(Logging.LogType.DEBUG);
            client.DeleteLogMessages(Logging.LogType.ERROR);
            client.DeleteLogMessages(Logging.LogType.INFO);
            client.DeleteLogMessages(Logging.LogType.WARNING);

            // Konvertiert Flieskommazahlen von float/double zu einem String mit zwei Dezimalstellen:
            NumberFormatInfo provider = new NumberFormatInfo();
            provider.NumberDecimalDigits = 2;

            // ** Ab diesem Punkt ist das Handling von Exceptions Voraussetzung: **

            try
            {
                // Alle relevanten Transaktionsdaten setzen:
                client.SetUsername(txtBox_Username.Text);
                client.SetPassword(txtBox_Password.Text);
                client.SetMtID(txtBox_MtID.Text);
                client.SetSubID(txtBox_subID.Text);
                client.SetAmount(txtBox_Amount.Text);
                client.SetCurrency(txtBox_Currency.Text);
                client.SetOkURL(txtBox_OKURL.Text);
                client.SetnOKURL(txtBox_NokURL.Text);
                client.SetMerchantClientID(txtBox_MerchantClientID.Text);
                client.SetPnURL(txtBox_PnURL.Text);
                client.SetShopID(txtBox_ShopID.Text);
                client.SetShopLabel(txtBox_ShopLabel.Text);

                client.SetRestrictedCountry("DE");
                client.SetRestrictedCountry("GB");

                //client.SetMinAge("12");
                //client.SetMinKycLevel("SIMPLE");
                
                // In diesem Beispiel handelt es sich um einen Test:
                client.SetStatus(DevStatus.TEST);

                // Bisher keine Exception ausgelöst, alle Eingaben sind valide:
                dataColl_lbl.ForeColor = Color.FromArgb(0, 0, 0);

                // Jede SOAP-Methode gibt ein Objekt zurück, welches alle die in der PaysafeCard wsdl-Datei spezifizierten 
                // Rückgabewerte enthält. 

                // Prüfe ob der Kunde existiert und die Zugangsdaten korrekt sind:
                SOPGClassicMerchantClient.com.paysafecard.soatest.GetMidReturn midRet = client.ConfirmMerchantData();

                if (midRet.resultCode == 0 && midRet.errorCode == 0)
                {
                    txtBox_Password.BackColor = Color.FromArgb(255, 255, 255);
                    txtBox_Username.BackColor = Color.FromArgb(255, 255, 255);
                    merchChck_lbl.ForeColor = Color.FromArgb(0, 0, 0);
                    InputErrorTxt.Text = "";
                }

                else
                {
                    txtBox_Password.BackColor = Color.FromArgb(255, 255, 255);
                    txtBox_Username.BackColor = Color.FromArgb(255, 255, 255);
                    InputErrorTxt.Text = "Benutzername oder Kennwort falsch.";
                    return;
                }

                SOPGClassicMerchantClient.com.paysafecard.soatest.CreateDispositionReturn ret = client.CreateDisposition();

                soapRequTxtBox.Text += "Errorcode: " + ret.errorCode + "\r\n";
                soapRequTxtBox.Text += "mID: " + ret.mid + "\r\n";
                soapRequTxtBox.Text += "mtID: " + ret.mtid + "\r\n";
                soapRequTxtBox.Text += "Resultcode: " + ret.resultCode + "\r\n";
                soapRequTxtBox.Text += "subID: " + ret.subId + "\r\n";
                soapRequTxtBox.Text += "\r\n\r\n";

                createDispo_lbl.ForeColor = Color.FromArgb(0, 150, 0);

                // Öffne den generierten URL im Standardwebbrowser:
                System.Diagnostics.Process.Start(client.GetCustomerPanelURL());

                if (MessageBox.Show("Execute getSerialNumbers?", "Proceed", MessageBoxButtons.YesNo) == System.Windows.Forms.DialogResult.Yes)
                {
                    SOPGClassicMerchantClient.com.paysafecard.soatest.GetSerialNumbersReturn GsRet = client.GetSerialNumbers();

                    soapRequTxtBox.Text += "Amount: " + GsRet.amount + "\r\n";
                    soapRequTxtBox.Text += "Currency: " + GsRet.currency + "\r\n";
                    soapRequTxtBox.Text += "customerDetails: " + GsRet.customerDetails + "\r\n";
                    soapRequTxtBox.Text += "dispositionState: " + GsRet.dispositionState + "\r\n";
                    soapRequTxtBox.Text += "errorCode: " + GsRet.errorCode + "\r\n";
                    soapRequTxtBox.Text += "MtId: " + GsRet.mtid + "\r\n";
                    soapRequTxtBox.Text += "resultCode: " + GsRet.resultCode + "\r\n";
                    soapRequTxtBox.Text += "serialNumbers: " + GsRet.serialNumbers + "\r\n";
                    soapRequTxtBox.Text += "subId: " + GsRet.subId + "\r\n";
                    soapRequTxtBox.Text += "\r\n\r\n";

                    customerPanel_lbl.ForeColor = Color.FromArgb(0, 150, 0);
                }

                if (MessageBox.Show("Execute executeDebit?", "Proceed", MessageBoxButtons.YesNo) == System.Windows.Forms.DialogResult.Yes)
                {
                    SOPGClassicMerchantClient.com.paysafecard.soatest.ExecuteDebitReturn ExRet = client.ExecuteDebit();

                    soapRequTxtBox.Text += "errorCode: " + ExRet.errorCode + "\r\n";
                    soapRequTxtBox.Text += "mtid: " + ExRet.mtid + "\r\n";
                    soapRequTxtBox.Text += "resultCode: " + ExRet.resultCode + "\r\n";
                    soapRequTxtBox.Text += "subId: " + ExRet.subId + "\r\n";

                    execDebit_lbl.ForeColor = Color.FromArgb(0, 150, 0);
                }
            }

            catch (ArgumentException argEx)
            {
                InputErrorTxt.Text = argEx.Message;
            }

            catch (Exception ex)
            {
                logTxtBox.Text += "[Exception] " + ex.Message + "\r\n";
            }
        }

        private void txtBox_Amount_TextChanged(object sender, EventArgs e)
        {
            this.ConcatAmountCurrencyUrl();
        }

        private void txtBox_Currency_TextChanged(object sender, EventArgs e)
        {
            this.ConcatAmountCurrencyUrl();
        }

        private void ConcatAmountCurrencyUrl()
        {
            var url = string.Format("https://www.paysafecard.com/?currency={0}&amount={1}", this.txtBox_Amount.Text, this.txtBox_Currency.Text);
            this.txtBox_OKURL.Text = url;
            this.txtBox_PnURL.Text = url;
        }
    }
}
