﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Globalization;
using PSC;

/**
 * SOPGClassicMerchantClient Demo Code
 * 
 * @package psc-sdk
 * @copyright 2013 Paysafecard.com Wertkarten AG
 * @version 1.2
 * @since 0.1
 */

namespace MerchantClientTest
{
    public partial class MainWindow : Form
    {
        private PSC.SOPGClassicMerchantClient client;

        public MainWindow()
        {
            InitializeComponent();

            try
            {
                // Create a new instance of MerchantClient. In this example a exception would be throwed in the
                // constructor, if the given language is invalid.
                client = new PSC.SOPGClassicMerchantClient(true, "EN", true, DevStatus.TEST);

                // Each event from PSC SDK must be redirected to this application:
                client.logMessageEvent += new PSC.SOPGClassicMerchantClient.logMessageEventHandler(client_logMessageEvent);
            }

            catch (ArgumentException argEx)
            {
                InputErrorTxt.Text = argEx.Message;
                procPaymentBtn.Enabled = false;
            }
        }

        void client_logMessageEvent(object sender, Logging.LogMessage logMessage)
        {
            string logTypeStr = "";

            switch (logMessage.logType)
            {
                case Logging.LogType.DEBUG: logTypeStr = "DEBUG"; break;
                case Logging.LogType.ERROR: logTypeStr = "ERROR"; break;
                case Logging.LogType.INFO: logTypeStr = "INFO"; break;
                case Logging.LogType.WARNING: logTypeStr = "WARNING"; break;
            }

            if (logMessage.logType == Logging.LogType.DEBUG)
            {
                logTxtBox.Text += "[" + logTypeStr + "]: " + logMessage.callerFunc + ": " + 
                    logMessage.requResult + "\r\n";

                return;
            }

            logTxtBox.Text += "[" + logTypeStr + "]: " + logMessage.message + ": " + 
                logMessage.callParams + "\r\n";
        }

        // This part will be executed when the "Proc payment" button was clicked
        private void procPaymentBtn_Click(object sender, EventArgs e)
        {
            soapRequTxtBox.Clear();
            logTxtBox.Clear();

            client.DeleteLogMessages(Logging.LogType.DEBUG);
            client.DeleteLogMessages(Logging.LogType.ERROR);
            client.DeleteLogMessages(Logging.LogType.INFO);
            client.DeleteLogMessages(Logging.LogType.WARNING);

            // Converts floating point numbers (float/double) to strings with two decimal digits:
            NumberFormatInfo provider = new NumberFormatInfo();
            provider.NumberDecimalDigits = 2;

            // ** At this point exception handling is required: **

            try
            {
                // Set all relevant transaction values:
                client.SetUsername(txtBox_Username.Text);
                client.SetPassword(txtBox_Password.Text);
                client.SetMtID(txtBox_MtID.Text);
                client.SetSubID(txtBox_subID.Text);
                client.SetAmount(txtBox_Amount.Text);
                client.SetCurrency(txtBox_Currency.Text);
                client.SetOkURL(txtBox_OKURL.Text);
                client.SetnOKURL(txtBox_NokURL.Text);
                client.SetMerchantClientID(txtBox_MerchantClientID.Text);
                client.SetPnURL(txtBox_PnURL.Text);
                client.SetShopID(txtBox_ShopID.Text);
                client.SetShopLabel(txtBox_ShopLabel.Text);

                client.SetRestrictedCountry("DE");
                client.SetRestrictedCountry("GB");

                //client.SetMinAge("12");
                //client.SetMinKycLevel("SIMPLE");

                // In this example it's a test:
                client.SetStatus(DevStatus.TEST);

                // No exception was thrown at this point, inputs are correctly validated:
                dataColl_lbl.ForeColor = Color.FromArgb(0, 0, 0);

                // Each SOAP-method returns an object which contains all return values, as specified in the PaysafeCard wsdl-file

                // Check if merchant exists and credentials are valid:
                SOPGClassicMerchantClient.com.paysafecard.soatest.GetMidReturn midRet = client.ConfirmMerchantData();

                if (midRet.resultCode == 0 && midRet.errorCode == 0)
                {
                    txtBox_Password.BackColor = Color.FromArgb(255, 255, 255);
                    txtBox_Username.BackColor = Color.FromArgb(255, 255, 255);
                    merchChck_lbl.ForeColor = Color.FromArgb(0, 0, 0);
                    InputErrorTxt.Text = "";
                }

                else
                {
                    txtBox_Password.BackColor = Color.FromArgb(255, 255, 255);
                    txtBox_Username.BackColor = Color.FromArgb(255, 255, 255);
                    InputErrorTxt.Text = "Username or password wrong.";
                    return;
                }

                SOPGClassicMerchantClient.com.paysafecard.soatest.CreateDispositionReturn ret = client.CreateDisposition();

                soapRequTxtBox.Text += "Errorcode: " + ret.errorCode + "\r\n";
                soapRequTxtBox.Text += "mID: " + ret.mid + "\r\n";
                soapRequTxtBox.Text += "mtID: " + ret.mtid + "\r\n";
                soapRequTxtBox.Text += "Resultcode: " + ret.resultCode + "\r\n";
                soapRequTxtBox.Text += "subID: " + ret.subId + "\r\n";
                soapRequTxtBox.Text += "\r\n\r\n";

                createDispo_lbl.ForeColor = Color.FromArgb(0, 150, 0);

                // Open the generated URL in standard browser:
                System.Diagnostics.Process.Start(client.GetCustomerPanelURL());

                if (MessageBox.Show("Execute getSerialNumbers?", "Proceed", MessageBoxButtons.YesNo) == System.Windows.Forms.DialogResult.Yes)
                {
                    SOPGClassicMerchantClient.com.paysafecard.soatest.GetSerialNumbersReturn GsRet = client.GetSerialNumbers();

                    soapRequTxtBox.Text += "Amount: " + GsRet.amount + "\r\n";
                    soapRequTxtBox.Text += "Currency: " + GsRet.currency + "\r\n";
                    soapRequTxtBox.Text += "customerDetails: " + GsRet.customerDetails + "\r\n";
                    soapRequTxtBox.Text += "dispositionState: " + GsRet.dispositionState + "\r\n";
                    soapRequTxtBox.Text += "errorCode: " + GsRet.errorCode + "\r\n";
                    soapRequTxtBox.Text += "MtId: " + GsRet.mtid + "\r\n";
                    soapRequTxtBox.Text += "resultCode: " + GsRet.resultCode + "\r\n";
                    soapRequTxtBox.Text += "serialNumbers: " + GsRet.serialNumbers + "\r\n";
                    soapRequTxtBox.Text += "subId: " + GsRet.subId + "\r\n";
                    soapRequTxtBox.Text += "\r\n\r\n";

                    customerPanel_lbl.ForeColor = Color.FromArgb(0, 150, 0);
                }

                if (MessageBox.Show("Execute executeDebit?", "Proceed", MessageBoxButtons.YesNo) == System.Windows.Forms.DialogResult.Yes)
                {
                    SOPGClassicMerchantClient.com.paysafecard.soatest.ExecuteDebitReturn ExRet = client.ExecuteDebit();

                    soapRequTxtBox.Text += "errorCode: " + ExRet.errorCode + "\r\n";
                    soapRequTxtBox.Text += "mtid: " + ExRet.mtid + "\r\n";
                    soapRequTxtBox.Text += "resultCode: " + ExRet.resultCode + "\r\n";
                    soapRequTxtBox.Text += "subId: " + ExRet.subId + "\r\n";

                    execDebit_lbl.ForeColor = Color.FromArgb(0, 150, 0);
                }
            }

            catch (ArgumentException argEx)
            {
                InputErrorTxt.Text = argEx.Message;
            }

            catch (Exception ex)
            {
                logTxtBox.Text += "[Exception] " + ex.Message + "\r\n";
            }
        }
    }
}
